@@ -2,7 +2,7 @@
 /**
  * This file contains the Horde_Url class for manipulating URLs.
  *
- * Copyright 2009-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -267,8 +267,12 @@ class Horde_Url
             : parse_url($this->url, PHP_URL_PATH);
 
         if (strlen($this->pathInfo)) {
-            $url = rtrim($url, '/');
-            $url .= '/' . $this->pathInfo;
+            $url = rtrim($url, '/') . '/';
+            if ($raw) {
+                $url .= $this->pathInfo;
+            } else {
+                $url .= implode('/', array_map('rawurlencode', explode('/', $this->pathInfo)));
+            }
         }
 
         if ($params = $this->_getParameters()) {
